==> godot-3.2-beta2.tar.xz: godot-3.2-beta2/AUTHORS.md <==
# Godot Engine authors

Godot Engine is developed by a community of voluntary contributors who
contribute code, bug reports, documentation, artwork, support, etc.

It is impossible to list them all; nevertheless, this file aims at listing
the developers who contributed significant patches to this MIT licensed
source code. "Significant" is arbitrarily decided, but should be fair :)

GitHub usernames are indicated in parentheses, or as sole entry when no other
name is available.

## Project Founders

    Juan Linietsky (reduz)
    Ariel Manzur (punto-)

## Lead Developer

    Juan Linietsky (reduz)

## Project Manager

    Rémi Verschelde (akien-mga)

## Developers

(in alphabetical order, with over 10 commits excluding merges)

    Aaron Franke (aaronfranke)
    Alexander Holland (AlexHolly)
    Alket Rexhepi (alketii)
    Andrea Catania (AndreaCatania)
    Andreas Haas (Hinsbart)
    Andrii Doroshenko (Xrayez)
    Andy Moss (MillionOstrich)
    Anish Bhobe (KidRigger)
    Anton Yabchinskiy (a12n)
    Anutrix
    Aren Villanueva (kurikaesu)
    Ariel Manzur (punto-)
    Bastiaan Olij (BastiaanOlij)
    Ben Brookshire (sheepandshepherd)
    Benjamin Larsson (Nallebeorn)
    Bernard Liebl (poke1024)
    Błażej Szczygieł (zaps166)
    Bojidar Marinov (bojidar-bg)
    bruvzg
    Cameron Reikes (creikey)
    Camille Mohr-Daurat (pouleyKetchoupp)
    Carl Olsson (not-surt)
    Carter Anderson (cart)
    Chris Bradfield (cbscribe)
    Clay John (clayjohn)
    Dana Olson (adolson)
    Daniel J. Ramirez (djrm)
    Daniel Rakos (aqnuep)
    David Sichma (DavidSichma)
    Dharkael (lupoDharkael)
    Dmitry Koteroff (Krakean)
    DualMatrix
    Emmanuel Barroga (codecustard)
    Emmanuel Leblond (touilleMan)
    Eric Lasota (elasota)
    Erik Selecký (rxlecky)
    est31
    Fabian Mathews (supagu)
    Fabio Alessandrelli (Faless)
    Ferenc Arn (tagcup)
    Franklin Sobrinho (TheHX)
    Fredia Huya-Kouadio (m4gr3d)
    Geequlim
    George Marques (vnen)
    Gerrit Großkopf (Grosskopf)
    Gilles Roudiere (groud)
    Gordon MacPherson (RevoluPowered)
    Guilherme Felipe de C. G. da Silva (guilhermefelipecgs)
    Hanif Bin Ariffin (hbina)
    Hein-Pieter van Braam-Stewart (hpvb)
    Hiroshi Ogawa (hi-ogawa)
    homer666
    Hubert Jarosz (Marqin)
    Hugo Locurcio (Calinou)
    Ian Bishop (ianb96)
    Ibrahn Sahir (ibrahn)
    Ignacio Etcheverry (neikeq)
    Ilaria Cislaghi (QbieShay)
    Indah Sylvia (ISylvox)
    J08nY
    Jakub Grzesik (kubecz3k)
    Jérôme Gully (Nutriz)
    Joan Fons Sanchez (JFonS)
    Johan Manuel (29jm)
    Joshua Grams (JoshuaGrams)
    Juan Linietsky (reduz)
    Julian Murgia (StraToN)
    Justo Delgado (mrcdk)
    Kelly Thomas (KellyThomas)
    Kostadin Damyanov (Max-Might)
    K. S. Ernest (iFire) Lee (fire)
    Leon Krause (eska014)
    Lucien Menassol (Kanabenki)
    m4nu3lf
    Marcelo Fernandez (marcelofg55)
    Marc Gilleron (Zylann)
    Marcin Zawiejski (dragmz)
    Mariano Javier Suligoy (MarianoGnu)
    Mario Schlack (hurikhan)
    Martin Capitanio (capnm)
    Martin Liška (marxin)
    Martin Sjursen (binbitten)
    marynate
    Masoud BH (masoudbh3)
    Matthias Hölzl (hoelzl)
    Max Hilbrunner (mhilbrunner)
    merumelu
    Michael Alexsander (YeldhamDev)
    MichiRecRoom (LikeLakers2)
    mrezai
    Nathan Warden (NathanWarden)
    Nils André-Chang (NilsIrl)
    Nuno Donato (nunodonato)
    Ovnuniarchos
    Pascal Richter (ShyRed)
    Patrick (firefly2442)
    Paul Batty (Paulb23)
    Paul Joannon (paulloz)
    Paul Trojahn (ptrojahn)
    Pawel Kowal (pkowal1982)
    Pedro J. Estébanez (RandomShaper)
    Pieter-Jan Briers (PJB3005)
    Poommetee Ketson (Noshyaar)
    Przemysław Gołąb (n-pigeon)
    Rafał Mikrut (qarmin)
    Ralf Hölzemer (rollenrolm)
    Ramesh Ravone (RameshRavone)
    raphael10241024
    Ray Koopa (RayKoopa)
    Rémi Verschelde (akien-mga)
    Rhody Lugo (rraallvv)
    Roberto F. Arroyo (robfram)
    Robin Hübner (profan)
    romulox-x
    Ruslan Mustakov (endragor)
    Saniko (sanikoyes)
    santouits
    SaracenOne
    sersoong
    Shiqing (kawa-yoiko)
    Simon Wenner (swenner)
    Swarnim Arun (minraws)
    Theo Hallenius (TheoXD)
    Thomas Herzog (karroffel)
    Timo Schwarzer (timoschwarzer)
    Timo (toger5)
    Tomasz Chabora (KoBeWi)
    Twarit Waikar (IronicallySerious)
    Vinzenz Feenstra (vinzenz)
    박한얼 (volzhs)
    V. Vamsi Krishna (vkbsb)
    Wilhem Barbier (nounoursheureux)
    Will Nations (willnationsdev)
    Wilson E. Alvarez (Rubonnek)
    Xavier Cho (mysticfall)
    yg2f (SuperUserNameMan)
    Yuri Roubinsky (Chaosus)
    Zher Huei Lee (leezh)
    ZuBsPaCe

==> godot-3.2.2-beta2.tar.xz: godot-3.2.2-beta2/AUTHORS.md <==
# Godot Engine authors

Godot Engine is developed by a community of voluntary contributors who
contribute code, bug reports, documentation, artwork, support, etc.

It is impossible to list them all; nevertheless, this file aims at listing
the developers who contributed significant patches to this MIT licensed
source code. "Significant" is arbitrarily decided, but should be fair :)

GitHub usernames are indicated in parentheses, or as sole entry when no other
name is available.

## Project Founders

    Juan Linietsky (reduz)
    Ariel Manzur (punto-)

## Lead Developer

    Juan Linietsky (reduz)

## Project Manager

    Rémi Verschelde (akien-mga)

## Developers

(in alphabetical order, with over 10 commits excluding merges)

    Aaron Franke (aaronfranke)
    Alexander Holland (AlexHolly)
    Alexey Khoroshavin (allkhor)
    Alket Rexhepi (alketii)
    Andrea Catania (AndreaCatania)
    Andreas Haas (Hinsbart)
    Andrii Doroshenko (Xrayez)
    Andy Moss (MillionOstrich)
    Anish Bhobe (KidRigger)
    Anton Yabchinskiy (a12n)
    Anutrix
    Aren Villanueva (kurikaesu)
    Ariel Manzur (punto-)
    Bastiaan Olij (BastiaanOlij)
    Ben Brookshire (sheepandshepherd)
    Benjamin Larsson (Nallebeorn)
    Bernard Liebl (poke1024)
    Błażej Szczygieł (zaps166)
    Bojidar Marinov (bojidar-bg)
    Bruno Lourenço (MadEqua)
    bruvzg
    Cameron Reikes (creikey)
    Camille Mohr-Daurat (pouleyKetchoupp)
    Carl Olsson (not-surt)
    Carter Anderson (cart)
    Chris Bradfield (cbscribe)
    Clay John (clayjohn)
    Dana Olson (adolson)
    Daniel J. Ramirez (djrm)
    Daniel Rakos (aqnuep)
    dankan1890
    David Sichma (DavidSichma)
    Dharkael (lupoDharkael)
    Dmitry Koteroff (Krakean)
    Dominik Jasiński (dreamsComeTrue)
    DualMatrix
    Emmanuel Barroga (codecustard)
    Emmanuel Leblond (touilleMan)
    Eoin O'Neill (Eoin-ONeill-Yokai)
    Eric Lasota (elasota)
    Eric Rybicki (ericrybick)
    Erik Selecký (rxlecky)
    est31
    Fabian Mathews (supagu)
    Fabio Alessandrelli (Faless)
    Ferenc Arn (tagcup)
    Franklin Sobrinho (TheHX)
    Fredia Huya-Kouadio (m4gr3d)
    Geequlim
    George Marques (vnen)
    Gerrit Großkopf (Grosskopf)
    Gilles Roudiere (groud)
    Gordon MacPherson (RevoluPowered)
    Guilherme Felipe de C. G. da Silva (guilhermefelipecgs)
    Hanif Bin Ariffin (hbina)
    Haoyu Qiu (timothyqiu)
    Hein-Pieter van Braam-Stewart (hpvb)
    Hiroshi Ogawa (hi-ogawa)
    homer666
    Hubert Jarosz (Marqin)
    Hugo Locurcio (Calinou)
    Ian Bishop (ianb96)
    Ibrahn Sahir (ibrahn)
    Ignacio Etcheverry (neikeq)
    Ilaria Cislaghi (QbieShay)
    Indah Sylvia (ISylvox)
    J08nY
    Jakub Grzesik (kubecz3k)
    Jérôme Gully (Nutriz)
    Joan Fons Sanchez (JFonS)
    Johan Manuel (29jm)
    Joshua Grams (JoshuaGrams)
    Juan Linietsky (reduz)
    Julian Murgia (StraToN)
    Justo Delgado (mrcdk)
    Kelly Thomas (KellyThomas)
    Kostadin Damyanov (Max-Might)
    K. S. Ernest (iFire) Lee (fire)
    lawnjelly
    Leon Krause (eska014)
    Lucien Menassol (Kanabenki)
    m4nu3lf
    Marcel Admiraal (madmiraal)
    Marcelo Fernandez (marcelofg55)
    Marc Gilleron (Zylann)
    Marcin Zawiejski (dragmz)
    Mariano Javier Suligoy (MarianoGnu)
    Mario Schlack (hurikhan)
    Martin Capitanio (capnm)
    Martin Liška (marxin)
    Martin Sjursen (binbitten)
    marynate
    Masoud BH (masoudbh3)
    Mateo Kuruk Miccino (kuruk-mm)
    Matthias Hölzl (hoelzl)
    Max Hilbrunner (mhilbrunner)
    merumelu
    Michael Alexsander (YeldhamDev)
    MichiRecRoom (LikeLakers2)
    mrezai
    muiroc
    Nathan Warden (NathanWarden)
    Nils André-Chang (NilsIrl)
    Nuno Donato (nunodonato)
    Ovnuniarchos
    Pascal Richter (ShyRed)
    Patrick (firefly2442)
    Paul Batty (Paulb23)
    Paul Joannon (paulloz)
    Paul Trojahn (ptrojahn)
    Pawel Kowal (pkowal1982)
    Pedro J. Estébanez (RandomShaper)
    Pieter-Jan Briers (PJB3005)
    Poommetee Ketson (Noshyaar)
    Przemysław Gołąb (n-pigeon)
    Rafał Mikrut (qarmin)
    Ralf Hölzemer (rollenrolm)
    Ramesh Ravone (RameshRavone)
    raphael10241024
    Ray Koopa (RayKoopa)
    Rémi Verschelde (akien-mga)
    Rhody Lugo (rraallvv)
    Roberto F. Arroyo (robfram)
    Robin Hübner (profan)
    romulox-x
    Ruslan Mustakov (endragor)
    Saniko (sanikoyes)
    santouits
    SaracenOne
    sersoong
    Shiqing (kawa-yoiko)
    Simon Wenner (swenner)
    Swarnim Arun (minraws)
    Thakee Nathees (ThakeeNathees)
    Theo Hallenius (TheoXD)
    Thomas Herzog (karroffel)
    Timo Schwarzer (timoschwarzer)
    Timo (toger5)
    Tomasz Chabora (KoBeWi)
    Twarit Waikar (IronicallySerious)
    Vinzenz Feenstra (vinzenz)
    박한얼 (volzhs)
    V. Vamsi Krishna (vkbsb)
    Wilhem Barbier (nounoursheureux)
    Will Nations (willnationsdev)
    Wilson E. Alvarez (Rubonnek)
    Xavier Cho (mysticfall)
    yg2f (SuperUserNameMan)
    Yuri Roubinsky (Chaosus)
    Zak Stam (zaksnet)
    Zher Huei Lee (leezh)
    ZuBsPaCe
